@@ -53,6 +53,7 @@ ggiplot = function(
   vcov    = if (!is.null(dots[['vcov']])) dots[['vcov']] else NULL
   cluster = if (!is.null(dots[['cluster']])) dots[['cluster']] else NULL
   se      = if (!is.null(dots[['se']])) dots[['se']] else NULL
+  multi_vcov = !is.null(vcov) && inherits(vcov, 'list') && length(vcov) > 1
 
   # The next few blocks grab the underlying iplot/coefplot data, contingent on the
   # object that was passed into the function (i.e. fixest, fixest_multi, or
@@ -87,6 +88,9 @@ ggiplot = function(
           fct_vars = setdiff(fct_vars, "sample.var") # also drop sample.var col
           fct_vars = stats::reformulate(fct_vars)
           n_fcts = length(unique(data$id))
+      } else if (multi_vcov) {
+          fct_vars = "id"
+          n_fcts = length(unique(data$id))
       } else {
           multi_style = "none"
       }
@@ -97,6 +101,7 @@ ggiplot = function(
           data = lapply(
               object, iplot_data_func,
               .ci_level = ci_level, .dict = dict, .aggr_es = aggr_eff,
+              .keep = keep, .drop = drop,
               .group = group, .i.select = i.select,
               .vcov = vcov, .cluster = cluster, .se = se
           )
@@ -106,6 +111,7 @@ ggiplot = function(
               	object, iplot_data_func,
               	.ci_level = ci_l,
               	.dict = dict, .aggr_es = aggr_eff,
+                .keep = keep, .drop = drop, 
               	.group = group, .i.select = i.select,
               	.vcov = vcov, .cluster = cluster, .se = se
               )
@@ -126,6 +132,7 @@ ggiplot = function(
       }
       rm(zz)
       data = do.call("rbind", data)
+      data$group = factor(data$group, levels = nms) ## keep original order
       rownames(data) = NULL
       if (length(unique(data$id)) == 1) {
           fct_vars = ~group
@@ -241,9 +248,12 @@ ggiplot = function(
   }
 
 
-  gg =
-      gg +
-      geom_vline(xintercept = ref.line, col = ref.line.par$col, lwd = ref.line.par$lwd, lty = ref.line.par$lty) +
+  gg = gg +
+  	{
+  		if (!is.null(ref.line) && ref.line != "auto") {
+	      geom_vline(xintercept = ref.line, col = ref.line.par$col, lwd = ref.line.par$lwd, lty = ref.line.par$lty)
+  		}
+  	} +
       {
           if (zero) {
               geom_hline(yintercept = 0, col = zero.par$col, lwd = zero.par$lwd, lty = zero.par$lty)
